"""
Command to load fixtures for Resume Manager Core models.
"""

# Third-Party Imports.
from django.contrib.auth import get_user_model
from django.core.management import call_command
from django.core.management.base import BaseCommand

# Internal Imports.
from apps.Resume_Manager.resume_manager_core.models import (
    Resume,
    ResumeTheme,
    ResumeSection,
    # ResumeToSectionIntermediary,
    # DataSectionHeader,
    # DataItem,
    # DataKeyValue,
)
from workspace_core.settings.reusable_settings import ConsoleColors


class Command(BaseCommand):
    help = 'Load fixtures into database models for Resume Manager Core app.'

    def handle(self, *args, **kwargs):
        """
        The logic of the command.
        """
        print('{0}RESUME_MANAGER_CORE{1}: {2}Load Fixtures{3} command has been called.'.format(
            ConsoleColors.purple,
            ConsoleColors.reset,
            ConsoleColors.blue,
            ConsoleColors.reset,
        ))

        # Run fixture imports.
        self.populate_resume_themes()
        self.populate_resumes()
        self.populate_section_css()
        self.populate_resume_sections()
        self.populate_contact_info()
        self.populate_education_instances()
        self.populate_experience_instances()
        self.populate_skill_categories()
        self.populate_skill_instances()
        self.populate_reference_instances()

        print('{0}RESUME_MANAGER_CORE{1}: {2}Fixture Loading{3} complete.\n'.format(
            ConsoleColors.purple,
            ConsoleColors.reset,
            ConsoleColors.blue,
            ConsoleColors.reset,
        ))

    def populate_resume_themes(self):
        """
        Loads fixtures for ResumeTheme models.
        """
        call_command('loaddata', 'resume_manager/resume_themes.json')

    def populate_resumes(self):
        """
        Loads fixtures for Resume models.
        """
        call_command('loaddata', 'resume_manager/resumes.json')

    def populate_section_css(self):
        """
        Loads fixtures for SectionCss models.
        """
        call_command('loaddata', 'resume_manager/section_css.json')

    def populate_resume_sections(self):
        """
        Loads fixtures for ResumeSection models.
        """
        call_command('loaddata', 'resume_manager/resume_sections.json')

    def populate_contact_info(self):
        """
        Loads fixtures for ContactInfo models.
        """
        call_command('loaddata', 'resume_manager/contact_info.json')

    def populate_education_instances(self):
        """
        Loads fixtures for EducationInstance models.
        """
        call_command('loaddata', 'resume_manager/education_instances.json')

    def populate_experience_instances(self):
        """
        Loads fixtures for ExperienceInstance models.
        """
        call_command('loaddata', 'resume_manager/experience_instances.json')

    def populate_skill_categories(self):
        """
        Loads fixtures for SkillCategory models.
        """
        call_command('loaddata', 'resume_manager/skill_categories.json')

    def populate_skill_instances(self):
        """
        Loads fixtures for SkillInstance models.
        """
        call_command('loaddata', 'resume_manager/skill_instances.json')

    def populate_reference_instances(self):
        """
        Loads fixtures for ReferenceInstance models.
        """
        call_command('loaddata', 'resume_manager/reference_instances.json')
